@@ -35,8 +35,8 @@ package inc::MBX::Alien::FLTK::Platform::Windows::MSVC;
                                        : ' -lfltk2_images '
                      )
         );
-        $self->notes('include_dirs'  => {});
-        $self->notes('library_paths' => {});
+        $self->notes('include_dirs' => {});
+        $self->notes('lib_dirs'     => {});
 
         # Not all of FLTK is compatible/applicable with MSVC...
         my @remove = qw[WidgetAssociation.cxx];
@@ -73,7 +73,6 @@ package inc::MBX::Alien::FLTK::Platform::Windows::MSVC;
                     next;
                 };
                 if ($data =~ s[^(#\s*warning .+)$][//$1]mg) {
-                    warn $src;
                     printf
                         'Removing incompatible #warning pragmas from %s... ',
                         $src;
@@ -146,7 +145,7 @@ package inc::MBX::Alien::FLTK::Platform::Windows::MSVC;
         );
         for my $lib (keys %{$self->notes('libs_source')}) {
             $self->notes('libs_source')->{$lib}{'disabled'}++
-                if $lib =~ m[glut$]i;
+                if $lib =~ m[glut]i;
         }
         $self->notes(ldflags => $self->notes('ldflags')
             . ' ws2_32.lib kernel32.lib user32.lib gdi32.lib winspool.lib comdlg32.lib advapi32.lib msimg32.lib shell32.lib ole32.lib oleaut32.lib uuid.lib '
@@ -190,6 +189,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: CygWin.pm dc42150 2010-01-17 03:51:57Z sanko@cpan.org $
+=for git $Id$
 
 =cut
